/*
 * @Description: 班制相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-08-04 14:21:03
 */

import { ActionItem, BasicColumn } from '/@/components/Table';
import { buildUUID } from '/@/utils/uuid';
import { useI18n } from '/@/hooks/web/useI18n';
import { isNullOrUnDef } from '/@/utils/is';

const { t } = useI18n();
function _default() {
  const ActionColumn: BasicColumn = {
    width: 100,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right',
  };
  /**
   * @description: 一些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (type: string) => {
      return {
        action: 'go', //drawer(打开左侧抽屉框) | go(跳转到新的页面) | edit(如果是表格可编辑页面就是自定义方法)
        url: 'MES_SHIFT/High',
        params: {
          CODE: '0',
          ID: buildUUID(),
          Name: 'MES_SHIFT', //实体名
          Title: '新增班制', //标题
          pCode: 'SFTS_CODE', //主信息关键字段CODE
          IsID: false, //是否带过去侧边框的是ID，false就是CODE，true是ID
          ifSave: false,
          drawers: [
            {
              name: 'MES_SHIFT',
              code: 'SFTS_CODE',
              type: 'one',
              keyName: 'MES_SHIFT',
              order: 'SFT_CODE',
            },
            {
              name: 'MES_SHIFT_PRD',
              code: 'SFT_CODE',
              type: 'all',
              keyName: 'MES_SHIFT',
              order: 'SFT_CODE, SEQ',
            },
          ], //drawers是右边弹出增改侧框的名字列表
        },
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      if (!isNullOrUnDef(data[0])) {
        data[0].onClick = Edit.bind(null, args, params);
      }
      return data;
    },
    /**
     * @description: 弹出选择框成功返回方法
     * @param {*} d
     * @param {*} u
     * @return {*}
     */
    GetSelectSuccess: (d, u) => {
      return {
        ITEM_CODE: d.values['val'],
      };
    },
    /**
     * @description: 弹出选择框打开方法
     * @param {Fn} openItemModal
     * @return {*}
     */
    OpenSelectItem: (openItemModal: Fn, ...args) => {
      openItemModal(true, {
        title: '物料列表',
        schemas: [
          {
            field: 'ITEM_CODE',
            component: 'Input',
            label: '物料编码',
            colProps: {
              span: 12,
            },
          },
        ],
        ItemColumns: [
          {
            title: t('物料编码'),
            dataIndex: 'ITEM_CODE',
            resizable: true,
            sorter: true,
            width: 200,
          },
          {
            title: t('物料名称'),
            dataIndex: 'ITEM_NAME',
            resizable: true,
            sorter: true,
            width: 180,
          },
        ],
        tableName: 'BAS_ITEM',
        rowKey: 'ITEM_CODE',
        searchInfo: { TABLE_NAME: 'BAS_ITEM' },
      });
    },
    GetUseForm: () => {
      return {};
    },
  };

  /* 以下是内部方法，不export，供上面的方法调用 */

  /**
   * @description: 自定义编辑方法
   * @param {Fn} args
   * @param {*} params
   * @return {*}
   */
  function Edit(args: Fn[], params: {}) {
    const param = {
      CODE: params['record']['SFTS_CODE'], //CODE的值
      ID: params['record']['ID'], //ID值
      Name: 'MES_SHIFT', //实体名
      SessionName: 'MES_SHIFT_update', //SessionStorage的key
      Title: `编辑班制：${params['record']['SFTS_CODE']}`, //标题
      // pCode: 'SFTS_CODE', //主信息关键字段CODE，高级表单用下面drawers里的code
      IsID: false, //是否带过去侧边框的是ID，false就是CODE，true是ID
      ifSave: false,
      drawers: [
        {
          name: 'MES_SHIFT',
          code: 'SFTS_CODE',
          type: 'one',
          keyName: 'MES_SHIFT',
          order: 'SFT_CODE',
        }, //type: one-表示需要code: 'SFTS_CODE'只要唯一值
        {
          name: 'MES_SHIFT_PRD',
          code: 'SFT_CODE',
          type: 'all',
          keyName: 'MES_SHIFT',
          order: 'SFT_CODE,SEQ',
        }, //type: all-表示需要code: 'SFT_CODE'所有的值，keyName：表示需要所有值的code的实体名
      ], //drawers是右边弹出增改侧框的名字列表
    };
    // 将对象转换为JSON字符串并保存到sessionStorage
    sessionStorage.removeItem(`${param.SessionName}_params`);
    sessionStorage.setItem(`${param.SessionName}_params`, encodeURI(JSON.stringify(param)));
    args[5](
      `/MES_SHIFT/High/${encodeURI(JSON.stringify({ sName: param.SessionName, Name: param.Name }))}`,
    );
  }

  return [methods, ActionColumn];
}

export default _default;
